<?xml version="1.0" encoding="UTF-8"?>

<!-- XSLT file to convert the XML files from http://pages.ifrance.com/pages/visio/download.htm into the OSIS standard Bible XML encoding format.
To create one OSIS file for all the XML files which belong to a Bible module you can download on the page above run the following commands (linux):
	export FILES=`ls -a hausa/BIB/*.xml`
	xsltproc - -stringparam modulename HOUSA - -stringparam FILES "$FILES" - -output hausa.osis kabyle.xsl hausa/BIB/GEN.xml 
-->


<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                version="1.0">

<xsl:output	method="xml" 
	 	indent="yes" 
	 	encoding="utf-8" />


<xsl:template match="/">
	<osis>
		<xsl:attribute name="xsi">
			<xsl:text>http://www.w3.org/2001/XMLSchema-instance</xsl:text>
		</xsl:attribute>
		
		<xsl:attribute name="noNamespaceSchemaLocation">
			<xsl:text>http://www.bibletechnologies.net/osisCore.1.1.1.xsd</xsl:text>
		</xsl:attribute>
		
		<osisText>
			<xsl:attribute name="osisIDWork">
				<xsl:value-of select="$modulename" />
			</xsl:attribute>
			<xsl:attribute name="osisRefWork">
				<xsl:text>defaultReferenceScheme</xsl:text>
			</xsl:attribute>
			
			<div>
				<xsl:attribute name="type">
					<xsl:text>testament</xsl:text>
				</xsl:attribute>
				
				<xsl:call-template name="parse-first-file">				
					<xsl:with-param name="files">
						<xsl:value-of select="$FILES" />
					</xsl:with-param>
				</xsl:call-template>
			</div>
		</osisText>
	</osis>
</xsl:template>


<xsl:template name="parse-first-file">
	<xsl:param name="first-filename">
		<xsl:if test="string-length($files) &gt; 0">
			<xsl:value-of select="substring-before(normalize-space($files), ' ')" />
		</xsl:if>
	</xsl:param>
	
	<xsl:param name="other-filenames">
		<xsl:if test="(string-length($files) &gt; 0) and (string-length($first-filename) &gt; 0)">
			<xsl:value-of select="substring-after(normalize-space($files), $first-filename)" />
		</xsl:if>
	</xsl:param>
	
	<xsl:param name="filename">
		<xsl:if test="(string-length($first-filename) &gt; 0)">
			<xsl:value-of select="normalize-space($first-filename)" />
		</xsl:if>
		
		<xsl:if test="(string-length($first-filename) = 0) and (string-length($files &gt; 0))">
			<xsl:value-of select="normalize-space($files)" />
		</xsl:if>
	</xsl:param>
	
	<xsl:if test="string-length($filename) &gt; 0">
		<xsl:param name="bookid"><xsl:value-of select="normalize-space(document($filename)/book/@value)"/></xsl:param>
		<xsl:param name="book">
			<xsl:choose>
				<xsl:when test="$bookid = 'MAT'">Matthew</xsl:when>
				<xsl:when test="$bookid = 'MRK'">Mark</xsl:when>
				<xsl:when test="$bookid = 'LUK'">Luke</xsl:when>
				<xsl:when test="$bookid = 'JHN'">John</xsl:when>
				<xsl:when test="$bookid = 'ACT'">Acts</xsl:when>

				<xsl:otherwise><xsl:value-of select="$bookid" /></xsl:otherwise>
			</xsl:choose>
		</xsl:param>

	
		<xsl:apply-templates select="document($filename)/book">
			<xsl:with-param name="book">
				<xsl:value-of select="$book" />
			</xsl:with-param>
		</xsl:apply-templates>
	</xsl:if>	
	
	<xsl:if test="(string-length($other-filenames) &gt; 0) or ( (string-length($filename) &gt;  0) and ($filename != $other-filenames))">
		<xsl:message>
			<xsl:text>
			
			Processing: </xsl:text><xsl:value-of select="$filename" />			
			
			<xsl:text>			
			Files left: </xsl:text><xsl:value-of select="$other-filenames" />
		</xsl:message>
	
		<xsl:call-template name="parse-first-file">
			<xsl:with-param name="files">
				<xsl:value-of select="$other-filenames" />
			</xsl:with-param>		
		</xsl:call-template>	
	</xsl:if>	
		
</xsl:template>


<xsl:template match="book">
	<div>
		<xsl:attribute name="type">
			<xsl:text>book</xsl:text>
		</xsl:attribute>
		
		<xsl:attribute name="osisID">
			<xsl:value-of select="$book" />
		</xsl:attribute>
		
		
		<xsl:apply-templates select="child::c">
			<xsl:with-param name="book">
				<xsl:value-of select="$book" />
			</xsl:with-param>
		</xsl:apply-templates>
	</div>
</xsl:template>

<xsl:template match="c">
	<chapter>	
		<xsl:attribute name="osisID">
			<xsl:value-of select="concat($book, '.', child::cn)"/>
		</xsl:attribute>
		
		<xsl:apply-templates select="child::p">
			<xsl:with-param name="book"><xsl:value-of select="$book" /></xsl:with-param>
			
			<xsl:with-param name="chapter"><xsl:value-of select="normalize-space(child::cn)" /></xsl:with-param>			
		</xsl:apply-templates>
		
		<xsl:apply-templates select="child::q">
			<xsl:with-param name="book"><xsl:value-of select="$book" /></xsl:with-param>
			
			<xsl:with-param name="chapter"><xsl:value-of select="normalize-space(child::cn)" /></xsl:with-param>			
		</xsl:apply-templates>
	</chapter>
</xsl:template>


<xsl:template match="p">
	<p>
		<xsl:apply-templates select="child::*">
			<xsl:with-param name="book">
				<xsl:value-of select="$book" />
			</xsl:with-param>
			
			<xsl:with-param name="chapter">
				<xsl:value-of select="$chapter" />
			</xsl:with-param>
		</xsl:apply-templates>
	</p>
</xsl:template>

<xsl:template match="q">
	<p>
		<xsl:apply-templates select="child::*">
			<xsl:with-param name="book">
				<xsl:value-of select="$book" />
			</xsl:with-param>
			
			<xsl:with-param name="chapter">
				<xsl:value-of select="$chapter" />
			</xsl:with-param>
		</xsl:apply-templates>
	</p>
</xsl:template>


<xsl:template match="vn">
	<verse>
		<xsl:attribute name="osisID">
			<xsl:value-of select="concat($book, '.', $chapter, '.', normalize-space(.))"/>
		</xsl:attribute>
		
		<xsl:value-of select="normalize-space(following::text())" />
	</verse>
</xsl:template>

</xsl:stylesheet>